Orange3-Timeseries Documentation
================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/yahoo_finance
   widgets/as_timeseries
   widgets/interpolate
   widgets/aggregate
   widgets/difference
   widgets/seasonal_adjustment
   widgets/moving_transform
   widgets/correlogram
   widgets/periodogram
   widgets/line_chart
   widgets/spiralogram
   widgets/arima
   widgets/var
   widgets/model_evaluation
   widgets/granger_causality

.. alternative ordering:
   :glob:

   widgets/*

Python Scripting
----------------

.. toctree::
   :maxdepth: 2
      
   scripting
   reference

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

